summaryrefslogtreecommitdiffstats
path: root/kword/KWView.h
diff options
context:
space:
mode:
Diffstat (limited to 'kword/KWView.h')
-rw-r--r--kword/KWView.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kword/KWView.h b/kword/KWView.h
index 095633bf..f023e6c6 100644
--- a/kword/KWView.h
+++ b/kword/KWView.h
@@ -37,7 +37,7 @@
#include <kshortcut.h>
#include <KoZoomMode.h>
-#include <brush.h>
+#include <tqbrush.h>
#include <tqhbox.h>
class KWPage;
@@ -350,7 +350,7 @@ public slots:
void configure();
void configureCompletion();
- void newPageLayout( const KoPageLayout &layout );
+ void newPageLayout( const KoPageLayout &tqlayout );
void newLeftIndent( double leftIndent);
void newFirstIndent( double firstIndent);
void newRightIndent( double rightIndent);
@@ -487,7 +487,7 @@ protected slots:
void spellAddAutoCorrect (const TQString & originalword, const TQString & newword);
void slotApplyFont();
void slotApplyParag();
- void slotPageLayoutChanged( const KoPageLayout& layout );
+ void slotPageLayoutChanged( const KoPageLayout& tqlayout );
void slotChangeCaseState(bool b);
void slotChangeCutState(bool b);
void slotCorrectWord();
@@ -868,7 +868,7 @@ protected:
KWDocStruct *m_docStruct;
// The right side
- TQWidget *m_right; // The layout widget.
+ TQWidget *m_right; // The tqlayout widget.
KoTabChooser *m_tabChooser;
KoRuler *m_vertRuler;